Commit c9f5298b0e7a1c21da35618be33ae651cbcdbcef

Vicent Marti 2014-03-03T12:09:17

caps: Rename to features to avoid confusion

diff --git a/src/settings.c b/src/settings.c
index 3856735..644e71c 100644
--- a/src/settings.c
+++ b/src/settings.c
@@ -17,17 +17,17 @@ void git_libgit2_version(int *major, int *minor, int *rev)
 	*rev = LIBGIT2_VER_REVISION;
 }
 
-int git_libgit2_capabilities()
+int git_libgit2_features()
 {
 	return 0
 #ifdef GIT_THREADS
-		| GIT_CAP_THREADS
+		| GIT_HAS_THREADS
 #endif
 #if defined(GIT_SSL) || defined(GIT_WINHTTP)
-		| GIT_CAP_HTTPS
+		| GIT_HAS_HTTPS
 #endif
 #if defined(GIT_SSH)
-		| GIT_CAP_SSH
+		| GIT_HAS_SSH
 #endif
 	;
 }
diff --git a/tests/core/caps.c b/tests/core/caps.c
deleted file mode 100644
index 68a518e..0000000
--- a/tests/core/caps.c
+++ /dev/null
@@ -1,31 +0,0 @@
-#include "clar_libgit2.h"
-
-void test_core_caps__0(void)
-{
-	int major, minor, rev, caps;
-
-	git_libgit2_version(&major, &minor, &rev);
-	cl_assert_equal_i(LIBGIT2_VER_MAJOR, major);
-	cl_assert_equal_i(LIBGIT2_VER_MINOR, minor);
-	cl_assert_equal_i(LIBGIT2_VER_REVISION, rev);
-
-	caps = git_libgit2_capabilities();
-
-#ifdef GIT_THREADS
-	cl_assert((caps & GIT_CAP_THREADS) != 0);
-#else
-	cl_assert((caps & GIT_CAP_THREADS) == 0);
-#endif
-
-#if defined(GIT_SSL) || defined(GIT_WINHTTP)
-	cl_assert((caps & GIT_CAP_HTTPS) != 0);
-#else
-	cl_assert((caps & GIT_CAP_HTTPS) == 0);
-#endif
-
-#if defined(GIT_SSH)
-	cl_assert((caps & GIT_CAP_SSH) != 0);
-#else
-	cl_assert((caps & GIT_CAP_SSH) == 0);
-#endif
-}
diff --git a/tests/core/features.c b/tests/core/features.c
new file mode 100644
index 0000000..b8c9003
--- /dev/null
+++ b/tests/core/features.c
@@ -0,0 +1,31 @@
+#include "clar_libgit2.h"
+
+void test_core_features__0(void)
+{
+	int major, minor, rev, caps;
+
+	git_libgit2_version(&major, &minor, &rev);
+	cl_assert_equal_i(LIBGIT2_VER_MAJOR, major);
+	cl_assert_equal_i(LIBGIT2_VER_MINOR, minor);
+	cl_assert_equal_i(LIBGIT2_VER_REVISION, rev);
+
+	caps = git_libgit2_features();
+
+#ifdef GIT_THREADS
+	cl_assert((caps & GIT_HAS_THREADS) != 0);
+#else
+	cl_assert((caps & GIT_HAS_THREADS) == 0);
+#endif
+
+#if defined(GIT_SSL) || defined(GIT_WINHTTP)
+	cl_assert((caps & GIT_HAS_HTTPS) != 0);
+#else
+	cl_assert((caps & GIT_HAS_HTTPS) == 0);
+#endif
+
+#if defined(GIT_SSH)
+	cl_assert((caps & GIT_HAS_SSH) != 0);
+#else
+	cl_assert((caps & GIT_HAS_SSH) == 0);
+#endif
+}
diff --git a/include/git2/common.h b/include/git2/common.h
index 4927154..49ffd01 100644
--- a/include/git2/common.h
+++ b/include/git2/common.h
@@ -94,29 +94,34 @@ GIT_BEGIN_DECL
 GIT_EXTERN(void) git_libgit2_version(int *major, int *minor, int *rev);
 
 /**
  * Combinations of these values describe the capabilities of libgit2.
  */
 typedef enum {
-	GIT_CAP_THREADS			= ( 1 << 0 ),
-	GIT_CAP_HTTPS			= ( 1 << 1 ),
-	GIT_CAP_SSH				= ( 1 << 2 ),
+	GIT_HAS_THREADS	= (1 << 0),
+	GIT_HAS_HTTPS = (1 << 1),
+	GIT_HAS_SSH = (1 << 2),
 } git_cap_t;
 
 /**
  * Query compile time options for libgit2.
  *
- * @return A combination of GIT_CAP_* values.
+ * @return A combination of GIT_HAS_* values.
  *
- * - GIT_CAP_THREADS
+ * - GIT_HAS_THREADS
  *   Libgit2 was compiled with thread support. Note that thread support is
  *   still to be seen as a 'work in progress' - basic object lookups are
  *   believed to be threadsafe, but other operations may not be.
  *
- * - GIT_CAP_HTTPS
+ * - GIT_HAS_HTTPS
  *   Libgit2 supports the https:// protocol. This requires the openssl
  *   library to be found when compiling libgit2.
+ *
+ * - GIT_HAS_SSH
+ *   Libgit2 supports the SSH protocol for network operations. This requires
+ *   the openssh to be found when compiling libgit2
  */
-GIT_EXTERN(int) git_libgit2_capabilities(void);
+GIT_EXTERN(int) git_libgit2_features(void);
 
 
 typedef enum {
@@ -94,29 +94,34 @@ GIT_BEGIN_DECL
 
 /**
- * Combinations of these values describe the capabilities of libgit2.
+ * Combinations of these values describe the features with which libgit2
+ * was compiled
  */
 typedef enum {